@@ -1,11 +1,12 @@
-#! perl
+#! perl --			-*- coding: utf-8 -*-
+
+use utf8;
 
-# RCS Id          : $Id: BTWAangifte.pm,v 1.47 2008/04/13 13:06:31 jv Exp $
 # Author          : Johan Vromans
 # Created On      : Tue Jul 19 19:01:33 2005
 # Last Modified By: Johan Vromans
-# Last Modified On: Sun Apr 13 15:06:03 2008
-# Update Count    : 633
+# Last Modified On: Thu Jan 26 16:40:41 2017
+# Update Count    : 653
 # Status          : Unknown, Use with caution!
 
 ################ Common stuff ################
@@ -20,8 +21,6 @@ package EB::Report::BTWAangifte;
 use strict;
 use warnings;
 
-our $VERSION = sprintf "%d.%03d", q$Revision: 1.47 $ =~ /(\d+)/g;
-
 use EB;
 use EB::Format;
 use EB::Booking;		# for norm_btw()
@@ -227,7 +226,7 @@ sub periode {
     }
     elsif ( $p == 12 ) {
 	return __x("{month} {year}",
-		   month => $EB::month_names[$v-1],
+		   month => _T( $EB::Utils::month_names[$v-1] ),
 		   year => $year);
     }
     else {
@@ -262,7 +261,7 @@ sub parse_periode {
     };
 
     my $yrpat = _T("j(aar)?");
-    if ( $v =~ /^$yrpat$|j(aar)?$/i ) {
+    if ( $v =~ /^$yrpat$|^j(aar)?$/i ) {
 	$pp->(1, 1);
 	return;
     }
@@ -277,8 +276,8 @@ sub parse_periode {
     if ( $v =~ /^(\w+)$/i ) {
 	my $i;
 	for ( $i = 0; $i < 12; $i++ ) {
-	    last if lc($EB::month_names[$i]) eq lc($v);
-	    last if lc($EB::months[$i]) eq lc($v);
+	    last if lc($EB::Utils::month_names[$i]) eq lc($v);
+	    last if lc($EB::Utils::months[$i]) eq lc($v);
 	}
 	if ( $i < 12 ) {
 	    $pp->(12, $i+1);
@@ -403,12 +402,13 @@ sub collect {
 		    $deb_0 += $amt;
 		}
 		elsif ( $btg_id == BTWTARIEF_PRIV ) {
-		    $tr->("Priv");
+		    $tr->("Privé");
 		    $deb_p += $amt;
 		    $deb_btw_p += $btw;
 		}
 		else {
-		    assert($btg_id == BTWTARIEF_ANDERS);
+		    confess( "BTWTARIEF NOT ANDERS" )
+		      unless $btg_id == BTWTARIEF_ANDERS;
 		    $tr->("Ander");
 		    $deb_a += $amt;
 		    $deb_btw_a += $btw;
@@ -524,11 +524,14 @@ sub collect {
     # 5b. Voorbelasting
     my ($vb) = @{$dbh->do("SELECT SUM(jnl_amount)".
 			  " FROM Journal".
-			  " WHERE ( jnl_acc_id = ? OR jnl_acc_id = ? )".
+			  " WHERE ( jnl_acc_id = ? OR jnl_acc_id = ?".
+			  "         OR jnl_acc_id = ? OR jnl_acc_id = ? )".
 			  " AND jnl_bsr_date >= ? AND jnl_bsr_date <= ?",
 			  $dbh->std_acc("btw_ih"), $dbh->std_acc("btw_il"),
+			  $dbh->std_acc("btw_ia",0), $dbh->std_acc("btw_ip",0),
 			  $begin, $end)};
     $vb ||= 0;	# prevent warnings
+    $vb += $intra_crd_btw;	# geheven intra btw terugvorderen
     my $btw_i_delta = $vb - $crd_btw - $intra_crd_btw;
     $v = roundup($vb);
     $data{vb} = $v;
@@ -698,24 +701,21 @@ sub report {
     my @msg;
     if ( $data->{btw_i_delta} ) {
 	push(@msg,
-	     __x("Er is een verschil van {round}{amount}".
+	     __x("Er is een verschil van {amount}".
 		 " tussen de berekende en werkelijk ingehouden BTW.".
 		 " Voor de aangifte is de werkelijk ingehouden waarde gebruikt.",
-		 round  => $noround ? "" : "(afgerond) ",
-		 amount => numfmt($noround ? $data->{btw_i_delta}
-				 : AMTSCALE*roundup($data->{btw_i_delta}))));
+		 amount => numfmt($data->{btw_i_delta})));
     }
 
     foreach my $type ( @{BTWTARIEVEN()} ) {
 	my $t = lc(substr($type, 0, 1));
 	if ( $data->{"btw_v".$t."_delta"} ) {
 	    push(@msg,
-		 __x("Er is een verschil van {round}{amount}".
+		 __x("Er is een verschil van {amount}".
 		     " tussen de berekende en werkelijk afgedragen BTW {type}.".
 		     " Voor de aangifte is de werkelijk afgedragen waarde gebruikt.",
 		     type   => $type,
-		     round  => $noround ? "" : "(afgerond) ",
-		     amount => numfmt(($noround ? 1 : AMTSCALE) * $data->{"btw_v".$t."_delta"})));
+		     amount => numfmt($data->{"btw_v".$t."_delta"})));
 	}
     }
 
@@ -774,33 +774,39 @@ sub kleine_ondernemers {
 
     # Formule lijkt linds 1995 ongwijzigd, alleen de bedragen
     # veranderen. Sinds 2002 zijn de bedragen ongewijzigd. Alle
-    # officile documentatie spreeekt over "Als de afdracht van
+    # officiële documentatie spreeekt over "Als de afdracht van
     # omzetbelasting beneden de 1.345 per jaar blijft, ...".
 
-    my %mmtab = ( 2002 => [ 1345, 1883 ],
-		  2003 => [ 1345, 1883 ],
-		  2004 => [ 1345, 1883 ],
-		  2005 => [ 1345, 1883 ],
-		  2006 => [ 1345, 1883 ],
-		  2007 => [ 1345, 1883 ],
-		);
+    # Code change: beschouw de huidige bedragen als vaststaand.
 
-    $mmtab{$year} ||= [ 1345, 1883 ] if $year >= 2002;
+    return if $year < 2002;
 
-    return unless exists $mmtab{$year};
+    # my %mmtab = ( 2002 => [ 1345, 1883 ],
+    #		  2003 => [ 1345, 1883 ],
+    #		  2004 => [ 1345, 1883 ],
+    #		  2005 => [ 1345, 1883 ],
+    #		  2006 => [ 1345, 1883 ],
+    #		  2007 => [ 1345, 1883 ],
+    #		);
+    #
+    # $mmtab{$year} ||= [ 1345, 1883 ] if $year >= 2002;
+    #
+    # return unless exists $mmtab{$year};
+    #
+    # my ($min, $max) = @{$mmtab{$year}};
+
+    my ($min, $max) = ( 1345, 1883 );
 
-    my ($min, $max) = @{$mmtab{$year}};
     if ( $noround ) {
 	$min *= AMTSCALE;
 	$max *= AMTSCALE;
     }
-    if ( $amount <= $min ) {
-	return $amount;
-    }
-    elsif ( $amount > $min && $amount <= $max ) {
-	return roundup(250 * ($max - $amount)) / ($noround ? AMTSCALE : 1);
-    }
-    return 0;
+
+    return $amount if $amount <= $min;
+    return 0       if $amount >  $max;
+
+    my $kko = ($min / ($max - $min)) * ($max - $amount);
+    return $noround ? $kko : roundup($kko*AMTSCALE);
 }
 
 sub warnings {
